<?php

/**
 * Plugin Name: GPT-trainer
 * Plugin URI: https://gpt-trainer.com
 * Description: Embed your AI chatbot on any WordPress site.
 * Version: 1.0.0
 * Author: GPT-trainer
 * Author URI: https://gpt-trainer.com/
 * License: GPL2
 */

add_action('admin_menu', 'render_gpt_trainer_options_page');

// Add the options page to the admin menu
function render_gpt_trainer_options_page()
{
    add_options_page('GPT-trainer Settings', 'GPT-trainer', 'administrator', 'gpt-trainer_uuid', 'gpt_trainer_options_page');
    add_action('admin_init', 'register_gpt_trainer_options');
}

// Register the options settings
function register_gpt_trainer_options()
{
    register_setting('gpt_trainer_options', 'gpt_trainer_uuid');
}

// Define the content of the options page
function gpt_trainer_options_page()
{
    ?>
    <div class="wrap">
        <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
        <div id="form-container">
            <form method="post" action="options.php">
                <?php settings_fields('gpt_trainer_options'); ?>
                <?php do_settings_sections('gpt_trainer_options'); ?>

                <div class="logo-container">
                    <a href="https://gpt-trainer.com/" target="_blank">
                        <img alt="GPT-trainer" loading="lazy" width="64" style="color:transparent"
                            src="https://app.gpt-trainer.com/img/logo-512.png">
                    </a>
                </div>

                <div class="form-group">
                    <label for="gpt_trainer_uuid" class="text-secondary">Chatbot UUID</label>
                    <input type="text" class="form-control" name="gpt_trainer_uuid" id="gpt_trainer_uuid"
                        value="<?php echo esc_attr(get_option('gpt_trainer_uuid')); ?>" required />
                </div>
                <label class="note-label">Copy your Chatbot UUID from the Chatbot Dashboard tab.</label>
                <div class="submit-btn-container">
                    <?php submit_button(); ?>
                </div>
            </form>
        </div>
    </div>
    <?php
}

// Enqueue admin styles for the settings page
function gpt_trainer_admin_styles($hook)
{
    if ($hook !== 'settings_page_gpt-trainer_uuid') {
        return;
    }

    wp_enqueue_style(
        'gpt-trainer-admin-css', 
        plugin_dir_url(__FILE__) . 'gpt-trainer.css',
        array(), 
        '1.0.0'
    );
}

// Embed the script on the site using the ID entered in the options page
function gpt_trainer_embed_chatbot()
{
    // Get the chatbot UUID from the settings
    $chatbot_uuid = get_option('gpt_trainer_uuid');
    if (!$chatbot_uuid) {
        return; // Don't load anything if UUID is missing
    }

    // Enqueue the external chatbot script
    wp_enqueue_script(
        'chatbot-script', // Handle
        'https://app.gpt-trainer.com/widget-asset.min.js', // Script URL
        array(), // Dependencies
        null, // Version (null means no versioning)
        true // Load in footer
    );

    // Add localized data to pass the UUID to the script
    wp_localize_script(
        'chatbot-script',
        'GPTTConfig', // The global variable name that the external script will use
        array(
            'uuid' => esc_js($chatbot_uuid), // Escaped late, sanitizing UUID for JavaScript
        )
    );
}

add_action('admin_enqueue_scripts', 'gpt_trainer_admin_styles');
add_action('wp_enqueue_scripts', 'gpt_trainer_embed_chatbot');

// Ensure the script is added only once
function prevent_multiple_loads() 
{
    if (!wp_script_is('chatbot-script', 'enqueued')) {
        gpt_trainer_embed_chatbot();
    }
}

add_action('wp_footer', 'prevent_multiple_loads');
?>
